@@ -1,16 +1,16 @@
-from mim.utils import read_installation_records
+from mim.commands.list import list_package
 
 
 def get_installed_package(ctx, args, incomplete):
     pkgs = []
-    for pkg, _, _ in read_installation_records():
+    for pkg, _, _ in list_package():
         pkgs.append(pkg)
     return pkgs
 
 
 def get_downstream_package(ctx, args, incomplete):
     pkgs = []
-    for pkg, _, _ in read_installation_records():
+    for pkg, _, _ in list_package():
         if pkg == 'mmcv' or pkg == 'mmcv-full':
             continue
         pkgs.append(pkg)
