@@ -238,7 +238,10 @@ def gridsearch(
             f'in codebase {package}, will use {files[0]} instead.')
         config = files[0]
 
-    train_script = osp.join(pkg_root, 'tools/train.py')
+    # tools will be put in package/.mim in PR #68
+    train_script = osp.join(pkg_root, '.mim', 'tools', 'train.py')
+    if not osp.exists(train_script):
+        train_script = osp.join(pkg_root, 'tools', 'train.py')
 
     # parsing search_args
     # the search_args looks like:
@@ -346,6 +349,11 @@ def gridsearch(
             ] + common_args
         elif launcher == 'slurm':
             parsed_srun_args = srun_args.split() if srun_args else []
+            has_job_name = any([('--job-name' in x) or ('-J' in x)
+                                for x in parsed_srun_args])
+            if not has_job_name:
+                job_name = osp.splitext(osp.basename(config_path))[0]
+                parsed_srun_args.append(f'--job-name={job_name}_train')
             cmd = [
                 'srun', '-p', f'{partition}', f'--gres=gpu:{gpus_per_node}',
                 f'--ntasks={gpus}', f'--ntasks-per-node={gpus_per_node}',
