@@ -3,7 +3,7 @@ import os.path as osp
 import shutil
 import tempfile
 from distutils.version import LooseVersion
-from pkg_resources import parse_requirements
+from pkg_resources import parse_requirements, resource_filename
 from typing import List
 
 import click
@@ -29,7 +29,6 @@ from mim.utils import (
     is_version_equal,
     parse_url,
     split_package_version,
-    write_installation_records,
 )
 
 
@@ -129,7 +128,15 @@ def install(package: str,
     target_pkg, target_version = split_package_version(package)
 
     # whether install from local repo
-    is_install_local_repo = osp.isdir(osp.abspath(target_pkg)) and not find_url
+    if looks_like_path(target_pkg):
+        if is_installable_dir(target_pkg):
+            is_install_local_repo = True
+        else:
+            raise ValueError(
+                highlighted_error(
+                    f'{target_pkg} is not a installable directory'))
+    else:
+        is_install_local_repo = False
 
     # whether install master branch from github
     is_install_master = bool(not target_version and find_url)
@@ -172,11 +179,7 @@ def install(package: str,
     if not find_url:
         find_url = infer_find_url(target_pkg)
 
-    # whether to write installation records to mmpackage.txt
-    is_record = False
-
     if is_install_local_repo:
-        is_record = True
         repo_root = osp.abspath(target_pkg)
         module_name, target_version = get_package_version(repo_root)
         if not module_name:
@@ -198,13 +201,11 @@ def install(package: str,
             is_editable=is_editable)
 
     elif find_url and find_url.find('git') >= 0 or is_install_master:
-        is_record = True
         install_from_github(target_pkg, target_version, find_url, timeout,
                             is_yes, is_user_dir, is_install_master)
     else:
         # if installing from wheel failed, it will try to install package by
         # building from source if possible.
-        is_record = bool(target_pkg in PKG2MODULE)
         try:
             install_from_wheel(target_pkg, target_version, find_url, timeout,
                                is_user_dir)
@@ -229,17 +230,41 @@ def install(package: str,
             else:
                 raise RuntimeError(highlighted_error(error))
 
-    if is_record:
-        if not target_version:
-            target_version = get_installed_version(target_pkg)
-        if is_install_local_repo:
-            find_url = 'local'
-
-        write_installation_records(target_pkg, target_version, find_url)
-
     echo_success(f'Successfully installed {target_pkg}.')
 
 
+def looks_like_path(name: str) -> bool:
+    """Checks whether the string "looks like" a path on the filesystem.
+
+    This does not check whether the target actually exists, only judge from the
+    appearance.
+
+    Args:
+        name (str): The string to be checked.
+    """
+    if osp.sep in name:
+        return True
+    if osp.altsep is not None and osp.altsep in name:
+        return True
+    if name.startswith('.'):
+        return True
+    return False
+
+
+def is_installable_dir(name: str) -> bool:
+    """Check whether path is a directory containing setup.py.
+
+    Args:
+        name (str): The string to be checked.
+    """
+    path = osp.abspath(name)
+    if osp.isdir(path):
+        setup_py = osp.join(path, 'setup.py')
+        return osp.isfile(setup_py)
+    else:
+        return False
+
+
 def infer_find_url(package: str) -> str:
     """Try to infer find_url if possible.
 
@@ -378,17 +403,20 @@ def install_from_repo(repo_root: str,
     """
 
     def copy_file_to_package():
-        items = ['tools', 'configs', 'model_zoo.yml']
+        # rename the model_zoo.yml to model-index.yml but support both of them
+        # for backward compatibility
+        filenames = ['tools', 'configs', 'model_zoo.yml', 'model-index.yml']
         module_name = PKG2MODULE.get(package, package)
-        pkg_root = osp.join(repo_root, module_name)
+        # configs, tools and model-index.yml will be copied to package/.mim
+        mim_root = resource_filename(module_name, '.mim')
+        os.makedirs(mim_root, exist_ok=True)
 
-        for item in items:
-            src_path = osp.join(repo_root, item)
-            dst_path = osp.join(pkg_root, item)
+        for filename in filenames:
+            src_path = osp.join(repo_root, filename)
+            dst_path = osp.join(mim_root, filename)
             if osp.exists(src_path):
                 if osp.islink(dst_path):
                     os.unlink(dst_path)
-
                 if osp.isfile(src_path):
                     shutil.copyfile(src_path, dst_path)
                 elif osp.isdir(src_path):
@@ -399,13 +427,20 @@ def install_from_repo(repo_root: str,
     def link_file_to_package():
         # When user installs package with editable mode, we should create
         # symlinks to package, which will synchronize the modified files.
-        items = ['tools', 'configs', 'model_zoo.yml']
+        # Besides, rename the model_zoo.yml to model-index.yml but support both
+        # of them for backward compatibility
+        filenames = ['tools', 'configs', 'model_zoo.yml', 'model-index.yml']
         module_name = PKG2MODULE.get(package, package)
         pkg_root = osp.join(repo_root, module_name)
+        # configs, tools and model-index.yml will be linked to package/.mim
+        mim_root = osp.join(pkg_root, '.mim')
+        os.makedirs(mim_root, exist_ok=True)
 
-        for item in items:
-            src_path = osp.join(repo_root, item)
-            dst_path = osp.join(pkg_root, item)
+        for filename in filenames:
+            src_path = osp.join(repo_root, filename)
+            dst_path = osp.join(mim_root, filename)
+            if osp.exists(dst_path):
+                continue
             if osp.exists(src_path):
                 if osp.isfile(dst_path) or osp.islink(dst_path):
                     os.remove(dst_path)
@@ -414,11 +449,6 @@ def install_from_repo(repo_root: str,
 
                 os.symlink(src_path, dst_path)
 
-    if is_editable:
-        link_file_to_package()
-    else:
-        copy_file_to_package()
-
     # install dependencies. For example,
     # install mmcls should install mmcv-full first if it is not installed or
     # its(mmcv) verison does not match.
@@ -428,7 +458,7 @@ def install_from_repo(repo_root: str,
         if dependencies:
             install_dependencies(dependencies, timeout, is_yes, is_user_dir)
 
-    third_dependencies = osp.join(repo_root, 'requirements', '/build.txt')
+    third_dependencies = osp.join(repo_root, 'requirements', 'build.txt')
     if osp.exists(third_dependencies):
         dep_cmd = [
             'python', '-m', 'pip', 'install', '-r', third_dependencies,
@@ -442,6 +472,10 @@ def install_from_repo(repo_root: str,
     install_cmd = ['python', '-m', 'pip', 'install']
     if is_editable:
         install_cmd.append('-e')
+    else:
+        # solving issues related to out-of-tree builds
+        # more datails at https://github.com/pypa/pip/issues/7555
+        install_cmd.append('--use-feature=in-tree-build')
     install_cmd.append(repo_root)
     if is_user_dir:
         install_cmd.append('--user')
@@ -456,6 +490,11 @@ def install_from_repo(repo_root: str,
 
     call_command(install_cmd)
 
+    if is_editable:
+        link_file_to_package()
+    else:
+        copy_file_to_package()
+
 
 def install_from_github(package: str,
                         version: str = '',
