@@ -228,7 +228,10 @@ def test(
         config = files[0]
 
     # We know that 'config' exists and is legal.
-    test_script = osp.join(pkg_root, 'tools/test.py')
+    test_script = osp.join(pkg_root, 'tools', 'test.py')
+    # tools will be put in package/.mim in PR #68
+    if not osp.exists(test_script):
+        test_script = osp.join(pkg_root, '.mim', 'tools', 'test.py')
 
     common_args = ['--launcher', launcher] + list(other_args)
 
@@ -248,6 +251,11 @@ def test(
         cmd += common_args
     elif launcher == 'slurm':
         parsed_srun_args = srun_args.split() if srun_args else []
+        has_job_name = any([('--job-name' in x) or ('-J' in x)
+                            for x in parsed_srun_args])
+        if not has_job_name:
+            job_name = osp.splitext(osp.basename(config))[0]
+            parsed_srun_args.append(f'--job-name={job_name}_test')
         cmd = [
             'srun', '-p', f'{partition}', f'--gres=gpu:{gpus_per_node}',
             f'--ntasks={gpus}', f'--ntasks-per-node={gpus_per_node}',
