@@ -1,5 +1,5 @@
 import os
-import pkg_resources
+import os.path as osp
 
 USER = 'open-mmlab'
 DEFAULT_URL = f'https://github.com/{USER}'
@@ -34,12 +34,7 @@ MODULE2PKG = {
     'mmseg': 'mmsegmentation',
 }
 
-DEFAULT_CACHE_DIR = f'{os.environ["HOME"]}/.cache/mim'
-if not os.path.exists(DEFAULT_CACHE_DIR):
+HOME = osp.expanduser('~')
+DEFAULT_CACHE_DIR = osp.join(HOME, '.cache', 'mim')
+if not osp.exists(DEFAULT_CACHE_DIR):
     os.makedirs(DEFAULT_CACHE_DIR)
-
-# Although site.getsitepackage() can also get the directory of site-packages,
-# it will faild in virtualenv. It is an issue with virtualenv, which copies
-# the bundled version of site.py to the venv when it is created.
-MMPACKAGE_PATH = os.path.join(
-    pkg_resources.get_distribution('click').location, 'mmpackage.txt')
